@@ -3,7 +3,7 @@ package Database::Async::ORM::Table;
 use strict;
 use warnings;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 sub new {
     my ($class, %args) = @_;
@@ -17,6 +17,12 @@ sub description { shift->{description} }
 sub tablespace { shift->{tablespace} }
 sub parents { (shift->{parents} //= [])->@* }
 sub fields { (shift->{fields} //= [])->@* }
+sub constraints { (shift->{constraints} //= [])->@* }
+sub foreign_keys { grep { $_->type eq 'foreign_key' } shift->constraints }
+sub primary_keys {
+    my ($self) = @_;
+    map { $self->field_by_name($_) } ($self->{primary_keys} // [])->@*
+}
 
 sub field_by_name {
     my ($self, $name) = @_;
